#
# spec file for package plasma-browser-integration
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define kf5_version 5.42.0
%define qt5_version 5.9.0
%bcond_with browser_extension
%bcond_without lang
Name:           plasma-browser-integration
Version:        5.18.5
Release:        bp153.2.2.1
Summary:        Helper for the KDE Plasma Browser Integration
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
Url:            https://cgit.kde.org/plasma-browser-integration.git
Source:         https://download.kde.org/stable/plasma/%{version}/plasma-browser-integration-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-browser-integration-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  cmake(KF5Activities) >= %{kf5_version}
BuildRequires:  cmake(KF5Crash) >= %{kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5FileMetaData) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{kf5_version}
BuildRequires:  cmake(KF5Purpose) >= %{kf5_version}
BuildRequires:  cmake(KF5Runner) >= %{kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
%if 0%{?suse_version} < 1330
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
BuildRequires:  gcc7-c++
%endif
Recommends:     %{name}-lang
Supplements:    packageand(plasma5-workspace:MozillaFirefox)
Supplements:    packageand(plasma5-workspace:chromium)
Supplements:    packageand(plasma5-workspace:GoogleChrome)
Supplements:    packageand(plasma5-workspace:opera)
Supplements:    packageand(plasma5-workspace:vivaldi)

%description
This package contains a helper binary necessary for the WebExtension to
work.

%package extension
Summary:        WebExtension for KDE Plamsa Browser Integration
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}

%description extension
This package contains a WebExtension to integrate the browser better into
KDE Plasma.

%lang_package

%prep
%setup -q

%build
%if 0%{?suse_version} < 1330
	# It does not build with the default compiler (GCC 4.8) on Leap 42.x
	export CC=gcc-7
	export CXX=g++-7
%endif

%if %{with browser_extension}
%cmake_kf5 -d build -- -DINSTALL_CHROME_MANIFEST=1
%else
%cmake_kf5 -d build -- -DINSTALL_CHROME_MANIFEST=0
%endif

%cmake_build

%install
%kf5_makeinstall -C build
if [ "%{_libdir}" != "%{_libexecdir}" ]; then
	# Move mozilla native messaging file to correct location
	mv %{buildroot}%{_libexecdir}/mozilla %{buildroot}%{_libdir}
fi
  %if %{with lang}
    %find_lang %{name} --all-name
  %endif

%files
%license COPYING*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kded
%dir %{_libdir}/mozilla
%dir %{_sysconfdir}/chromium
%dir %{_sysconfdir}/opt/chrome
%{_kf5_bindir}/plasma-browser-integration-host
%{_kf5_plugindir}/kf5/kded/browserintegrationreminder.so
%{_kf5_servicesdir}/plasma-runner-browsertabs.desktop
%{_libdir}/mozilla/native-messaging-hosts
%{_libqt5_plugindir}/krunner_browsertabs.so
%{_sysconfdir}/chromium/native-messaging-hosts
%{_sysconfdir}/opt/chrome/native-messaging-hosts

%if %{with browser_extension}
%files extension
%license COPYING*
%dir %{_datadir}/chromium
%dir %{_datadir}/chromium/extensions
%dir %{_datadir}/google-chrome
%dir %{_datadir}/google-chrome/extensions
%{_datadir}/chromium/extensions/cimiefiiaegbelhefglklhhakcgmhkai.json
%{_datadir}/google-chrome/extensions/cimiefiiaegbelhefglklhhakcgmhkai.json
%endif

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- Changes since 5.18.4.1:
  * Detect Vivaldi based on binary name
  * [Purpose Plugin] Detect cancelling the prompt more reliably
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- No code changes since 5.18.2
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- No code changes since 5.18.1
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- No code changes since 5.17.90
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * Bump manifest version
  * Remove duplicate include
  * Make tabbar code a bit more fool-proof
  * [Download Plugin] Register downloaded files as recent documents
  * Bump manifest version
  * Add icon to browser integration do not remind menu item
  * Disable purpose menu
  * Bump manifest version
  * Fix i18n pot to json extraction
  * Remove unused optional_permissions
  * Just return applicationDisplayName in MPRIS Identity
  * Don't add and remove player element if it is already in the page
  * Show startup error in popup as well
  * Fixup new Audio() constructor and apply autoplay prevention evasion to document.createElement (kde#411742)
  * Improve error reporting for port on Firefox
  * Fix clearing kde connect devices on disconnect
  * Add KDEClangFormat cmake support
  * Add per-origin media controls blacklist (kde#394126)
  * Add settings change listener
  * Move save failure message above options
  * Let plugin add additional status information
  * Remove comment
  * Let options page scroll
  * Add SettingsUtils utility class
  * Make .hidden super hidden
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- Changes since 5.17.4:
  * [Purpose Plugin] Reset pending reply serial when aborting
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- Changes since 5.17.0:
  * Bail out early when setPluginLoaded would result in no change
  * Show version information in about screen
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Too many changes to list here
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- Changes since 5.16.2:
  * i18n: use https for bugs.kde.org
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- Changes since 5.15.90:
  * [Downloads Plugin] Update existing job when being signalled creation of existing job
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * [DownloadJob] Set processed amount when download finishes
  * Revert "Update kf5 version requirement to 5.58.0" as previously KF5 and Qt minimum dependencies had deliberately set low as newer versions were not actually required, and it allows distributions to backport new p-b-i versions more easily where desired.
  * Remove kde connect context menu entries when host dies
  * Disallow setting a negative volume
  * Also handle muted property on player
  * Fix message extraction
  * Make really sure we show an error message in case saving failed
  * No multi-line in JSON, oopsie
  * Add store description to locale file for translations
  * [DownloadJob] Report total size only if known
  * Initialize metadata with null (kde#406782)
  * Bump manifest version and copyright
  * Call into native Media Session browser API if available
  * Keep player around when emptied but the website tells us it's actually just paused (kde#402324)
  * Support "stop" Media Sessions action handler
  * Only consider player gone if really no longer part of the visible DOM
  * Minimize code duplication between node and its children
  * Set Breeze scrollbars only on HTML tag
  * Remove player from known players list when it disappears
  * Avoid serializing base64 encoded favicon data twice
  * [DownloadJob] Set destUrl and total amount
  * Remove unused dependencies
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- Changes since 5.15.4:
  * Fix crash when mutating a container while iterating it
  * Send vivaldi-stable as DesktopEntry
* Thu Apr 25 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Fix kf5_version requirement
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- Changes since 5.15.3:
  * Update description before processing job state or error
  * [Host] Add Message.sh
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * Install message handler after QApplication (kde#400906)
  * Make media session property setter more resilient (kde#401636)
  * Bump manifest version
  * Include Breeze scrollbar CSS inline
  * Also catch new Audio() elements (kde#398261)
  * Connect to contextMenu clicked callback only once
  * Update about KDE text
  * Recreate interrupted download when it is resumed (kde#401038)
  * Send all active downloads on load
  * Fix removing KDE Connect device entry
  * Sort keys in json encoder
  * Bump manifest version
  * Wait for duration to be known before registering player
  * Bump manifest version
  * Make it compiles with KDEFrameworkCompilerSettings
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Only cancel job when an "error" is set and ignore "interrupted" (kde#385530)
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * Include actual player source in metadata
  * Listen to KDE Connect device signals
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- Changes since 5.14.1:
  * Lower Qt dependency to 5.9
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Sort keys in json encoder
  * [MPris Plugin] Support Seek()
  * Add Messages.sh (kde#398595)
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Too many changes to list here
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * Monitor document title (kde#395393)
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun 14 2018 wbauer@tmo.at
- Recommend lang package
* Sun Jun 10 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * Bump version number of extension in preparation for Plasma 5.13
  * Handle when the added node itself is audio/video
  * Don't bother loading on non-supported platforms
  * [Installation Reminder] Watch for service registration and hide
  * Respect libdir for Firefox native messaging host manifest
  * Use incognito tab icon only as a fallback
  * Filter out incognito tabs and media controls on Firefox
  * Revert "Install mozilla native messaging manifest to either /usr/lib or /usr/lib64 based on architecture"
  * Install mozilla native messaging manifest to either /usr/lib or /usr/lib64 based on architecture
  * Fix options page look on Firefox (kde#394369)
  * Handle children of added nodes as well
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.80:
  * Bump version number of extension in preparation for Plasma 5.13 beta
  * Set variable for chromium install dir
  * cmake: Don't install chrome manifest to ubuntu specific location (kde#393846)
  * Add link to Community Wiki page to About dialog
  * Remove superfluous <small> tags
  * Remove dead code and shut up
  * Implement reporting playback state via Media Sessions API
  * Observe entire DOM
  * UUID might start with a number which a variable is not allowed to
  * Also "randomize" plasmaMediaSessions global variable
  * WIP: Show SNI to install browser-side extension
  * Properly fix the native messaging host file
  * Hopefully handle messages spread across lines in .po files
  * Make "Translated by" credit work like in KAboutData
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.80git.20180502T081035~2c9d903
  * New bugfix release
  * For more details please see:
  * https://cgit.kde.org/plasma-browser-integration.git/log/?id=2c9d903dff81873bf04300290ead0c0eeafbd028
- Too many changes to list here
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Separate WebExtension into -extension subpackage
- Don't build it by default (enabled in KUE)
* Fri Jul 14 2017 fabian@ritter-vogt.de
- Move firefox file from /usr/lib into /usr/lib{,64}
* Fri Apr 28 2017 fabian@ritter-vogt.de
- Initial packaging
